@@ -12,6 +12,7 @@ use File::Which;
 use File::Copy qw(cp);
 use Cwd qw(realpath);
 
+our $cc = $Config{cc};
 #### packs with prebuilt binaries
 # - all regexps has to match: arch_re ~ $Config{archname}, cc_re ~ $Config{cc}, os_re ~ $^O
 # - the order matters, we offer binaries to user in the same order (1st = preffered)
@@ -90,17 +91,20 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
         ],
       },
       {
         pack => 'jpeg',
-        dirname => 'jpeg-8a',
+        dirname => 'jpeg-8b',
         url => [
-          'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
-          'http://froggs.de/libjpeg/jpegsrc.v8a.tar.gz',
+          'http://www.ijg.org/files/jpegsrc.v8b.tar.gz',
+          'http://froggs.de/libjpeg/jpegsrc.v8b.tar.gz',
+        ],
+        sha1sum  => '15dc1939ea1a5b9d09baea11cceb13ca59e4f9df',
+        patches => [
+          'jpeg-8a_cygwin.patch',
         ],
-        sha1sum  => '78077fb22f0b526a506c21199fbca941d5c671a9',
-        patches => [ 'jpeg-8a_cygwin.patch' ],
       },
       {
         pack => 'tiff',
@@ -151,16 +155,6 @@ my $source_packs = [
         sha1sum  => '98f6518ec71d94b8ad303a197445e0991850b887',
         patches => [ ],
       },
-      #{
-      #  pack => 'SDL_net',
-      #  dirname => 'SDL_net-1.2.7',
-      #  url => [
-      #    'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
-      #    'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
-      #  ],
-      #  sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
-      #  patches => [ ],
-      #},
       {
         pack => 'SDL_gfx',
         dirname => 'SDL_gfx-2.0.20',
@@ -212,6 +206,7 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
         ],
       },
       {
@@ -244,16 +239,6 @@ my $source_packs = [
         sha1sum  => '98f6518ec71d94b8ad303a197445e0991850b887',
         patches => [ ],
       },
-      #{
-      #  pack => 'SDL_net',
-      #  dirname => 'SDL_net-1.2.7',
-      #  url => [
-      #    'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
-      #    'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
-      #  ],
-      #  sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
-      #  patches => [ ],
-      #},
       {
         pack => 'SDL_gfx',
         dirname => 'SDL_gfx-2.0.20',
@@ -304,6 +289,7 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
         ],
       },
       {
@@ -320,13 +306,15 @@ my $source_packs = [
       },
       {
         pack => 'jpeg',
-        dirname => 'jpeg-8a',
+        dirname => 'jpeg-8b',
         url => [
-          'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
-          'http://froggs.de/libjpeg/jpegsrc.v8a.tar.gz',
+          'http://www.ijg.org/files/jpegsrc.v8b.tar.gz',
+          'http://froggs.de/libjpeg/jpegsrc.v8b.tar.gz',
+        ],
+        sha1sum  => '15dc1939ea1a5b9d09baea11cceb13ca59e4f9df',
+        patches => [
+          'jpeg-8a_cygwin.patch',
         ],
-        sha1sum  => '78077fb22f0b526a506c21199fbca941d5c671a9',
-        patches => [ 'jpeg-8a_cygwin.patch' ],
       },
       {
         pack => 'tiff',
@@ -377,16 +365,6 @@ my $source_packs = [
         sha1sum  => '98f6518ec71d94b8ad303a197445e0991850b887',
         patches => [ ],
       },
-      #{
-      #  pack => 'SDL_net',
-      #  dirname => 'SDL_net-1.2.7',
-      #  url => [
-      #    'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
-      #    'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
-      #  ],
-      #  sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
-      #  patches => [ ],
-      #},
       {
         pack => 'SDL_gfx',
         dirname => 'SDL_gfx-2.0.20',
@@ -419,6 +397,7 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
         ],
       },
       {
@@ -435,13 +414,15 @@ my $source_packs = [
       },
       {
         pack => 'jpeg',
-        dirname => 'jpeg-8a',
+        dirname => 'jpeg-8b',
         url => [
-          'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
-          'http://froggs.de/libjpeg/jpegsrc.v8a.tar.gz',
+          'http://www.ijg.org/files/jpegsrc.v8b.tar.gz',
+          'http://froggs.de/libjpeg/jpegsrc.v8b.tar.gz',
+        ],
+        sha1sum  => '15dc1939ea1a5b9d09baea11cceb13ca59e4f9df',
+        patches => [
+          'jpeg-8a_cygwin.patch',
         ],
-        sha1sum  => '78077fb22f0b526a506c21199fbca941d5c671a9',
-        patches => [ 'jpeg-8a_cygwin.patch' ],
       },
       {
         pack => 'tiff',
@@ -482,16 +463,6 @@ my $source_packs = [
         sha1sum  => 'ef5d45160babeb51eafa7e4019cec38324ee1a5d',
         patches => [ ],
       },
-      #{
-      #  pack => 'SDL_net',
-      #  dirname => 'SDL_net-1.2.7',
-      #  url => [
-      #    'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
-      #    'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
-      #  ],
-      #  sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
-      #  patches => [ ],
-      #},
       {
         pack => 'SDL_gfx',
         dirname => 'SDL_gfx-2.0.20',
@@ -528,13 +499,15 @@ my $source_packs = [
       },
       {
         pack => 'jpeg',
-        dirname => 'jpeg-8a',
+        dirname => 'jpeg-8b',
         url => [
-          'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
-          'http://froggs.de/libjpeg/jpegsrc.v8a.tar.gz',
+          'http://www.ijg.org/files/jpegsrc.v8b.tar.gz',
+          'http://froggs.de/libjpeg/jpegsrc.v8b.tar.gz',
+        ],
+        sha1sum  => '15dc1939ea1a5b9d09baea11cceb13ca59e4f9df',
+        patches => [
+          'jpeg-8a_cygwin.patch',
         ],
-        sha1sum  => '78077fb22f0b526a506c21199fbca941d5c671a9',
-        patches => [ 'jpeg-8a_cygwin.patch' ],
       },
       {
         pack => 'tiff',
@@ -574,6 +547,7 @@ my $source_packs = [
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
+          'SDL-1.2.14-openbsd-rldflags.patch',
         ],
       },
       {
@@ -606,16 +580,6 @@ my $source_packs = [
         sha1sum  => '98f6518ec71d94b8ad303a197445e0991850b887',
         patches => [ ],
       },
-      #{
-      #  pack => 'SDL_net',
-      #  dirname => 'SDL_net-1.2.7',
-      #  url => [
-      #    'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
-      #    'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
-      #  ],
-      #  sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
-      #  patches => [ ],
-      #},
       {
         pack => 'SDL_gfx',
         dirname => 'SDL_gfx-2.0.20',
@@ -654,12 +618,12 @@ sub check_config_script
 sub check_prebuilt_binaries
 {
   print "Gonna check availability of prebuilt binaries ...\n";
-  print "(os=$^O cc=$Config{cc} archname=$Config{archname})\n";
+  print "(os=$^O cc=$cc archname=$Config{archname})\n";
   my @good = ();
   foreach my $b (@{$prebuilt_binaries}) {
     if ( ($^O =~ $b->{os_re}) &&
          ($Config{archname} =~ $b->{arch_re}) &&
-         ($Config{cc} =~ $b->{cc_re}) ) {
+         ($cc =~ $b->{cc_re}) ) {
       $b->{buildtype} = 'use_prebuilt_binaries';
       push @good, $b;
     }
@@ -671,7 +635,7 @@ sub check_prebuilt_binaries
 sub check_src_build
 {
   print "Gonna check possibility for building from sources ...\n";
-  print "(os=$^O cc=$Config{cc})\n";
+  print "(os=$^O cc=$cc)\n";
   my @good = ();
   foreach my $p (@{$source_packs}) {
     $p->{buildtype} = 'build_from_sources';
@@ -692,6 +656,7 @@ sub check_prereqs_libs {
       '/usr/local/include' => '/usr/local/lib',
       '/usr/include'       => '/usr/lib',
       '/usr/X11R6/include' => '/usr/X11R6/lib',
+      '/usr/pkg/include'   => '/usr/pkg/lib',
     };
 
     if( -e '/usr/lib64'  && $Config{'myarchname'} =~ /64/) {
@@ -747,8 +712,10 @@ sub check_prereqs_tools {
 
   foreach my $tool (@tools) {
     
-    if(-x File::Which::which($tool)
-    || ('pkg-config' eq $tool && defined $ENV{PKG_CONFIG} && $ENV{PKG_CONFIG} && -x File::Which::which($ENV{PKG_CONFIG}))) {
+    if((File::Which::which($tool) && -x File::Which::which($tool))
+    || ('pkg-config' eq $tool && defined $ENV{PKG_CONFIG} && $ENV{PKG_CONFIG}
+                              && File::Which::which($ENV{PKG_CONFIG})
+                              && -x File::Which::which($ENV{PKG_CONFIG}))) {
       $ret &= 1;
     }
     else {
@@ -864,7 +831,6 @@ sub get_dlext {
   }
   elsif( $^O =~ /cygwin/)
   {  
-    warn 'USING la for cygwin';
     return 'la';
   }
   else {
